/// <reference types="react" />
import * as react from 'react';
import react__default, { ReactNode, RefObject } from 'react';
import * as react_jsx_runtime from 'react/jsx-runtime';
import * as styled_components from 'styled-components';
import * as styled_components_dist_types from 'styled-components/dist/types';
import * as react_router_dom from 'react-router-dom';
import { LinkProps } from 'react-router-dom';

declare const Input: react.ForwardRefExoticComponent<react.InputHTMLAttributes<HTMLInputElement> & {
    readonly label?: string | undefined;
    readonly prefixContent?: JSX.Element | undefined;
    readonly postfixContent?: JSX.Element | undefined;
} & react.RefAttributes<HTMLInputElement>>;

type WithChildren = {
    readonly children?: ReactNode | readonly ReactNode[];
};

type TopLabeledProps = WithChildren & {
    readonly label: string;
};
declare const TopLabeled: ({ children, label }: TopLabeledProps) => react_jsx_runtime.JSX.Element;

declare const Select: react__default.ForwardRefExoticComponent<react__default.SelectHTMLAttributes<HTMLSelectElement> & {
    readonly label?: string | undefined;
} & react__default.RefAttributes<HTMLSelectElement>>;
declare const Option: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react__default.DetailedHTMLProps<react__default.OptionHTMLAttributes<HTMLOptionElement>, HTMLOptionElement>, never>>;

declare const Label: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.LabelHTMLAttributes<HTMLLabelElement>, HTMLLabelElement>, never>>;

type InputsWrapperProps = {
    readonly fullWidth?: boolean;
};
declare const InputsWrapper: styled_components.IStyledComponent<"web", styled_components_dist_types.Substitute<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, InputsWrapperProps>>;
declare const InputsFullWidth: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;

type ToggleSwitchProps = {
    readonly label: string;
    readonly checked: boolean;
    readonly onClick: () => void;
};
declare const ToggleSwitch: ({ label, checked, onClick }: ToggleSwitchProps) => react_jsx_runtime.JSX.Element;

declare const TextArea: react.ForwardRefExoticComponent<react.InputHTMLAttributes<HTMLTextAreaElement> & {
    readonly label?: string | undefined;
} & react.RefAttributes<HTMLTextAreaElement>>;

type ButtonVariants = 'contained' | 'outlined' | 'text';
type ButtonProps = React.ButtonHTMLAttributes<HTMLButtonElement> & {
    readonly variant: ButtonVariants;
    readonly icon?: string;
    readonly loading?: boolean;
    readonly selected?: boolean;
};
declare const Button: react.ForwardRefExoticComponent<react.ButtonHTMLAttributes<HTMLButtonElement> & {
    readonly variant: ButtonVariants;
    readonly icon?: string | undefined;
    readonly loading?: boolean | undefined;
    readonly selected?: boolean | undefined;
} & react.RefAttributes<HTMLButtonElement>>;
type ButtonVariantProps = Omit<ButtonProps, 'variant'>;
declare const ContainedButton: (props: ButtonVariantProps) => react_jsx_runtime.JSX.Element;
declare const OutlinedButton: (props: ButtonVariantProps) => react_jsx_runtime.JSX.Element;
declare const TextButton: (props: ButtonVariantProps) => react_jsx_runtime.JSX.Element;

declare const Loading: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;

type DropdownContentProps = {
    readonly sideAnchor?: string;
};
declare const DropdownContent: styled_components.IStyledComponent<"web", styled_components_dist_types.Substitute<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, DropdownContentProps>>;
declare const Dropdown: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;
declare const DropdownLinkItem: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<Omit<react_router_dom.LinkProps & react.RefAttributes<HTMLAnchorElement>, "ref"> & {
    ref?: ((instance: HTMLAnchorElement | null) => void) | react.RefObject<HTMLAnchorElement> | null | undefined;
}, never>> & Omit<react.ForwardRefExoticComponent<react_router_dom.LinkProps & react.RefAttributes<HTMLAnchorElement>>, keyof react.Component<any, {}, any>>;

declare const StyledLinkButton: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<Omit<LinkProps & react.RefAttributes<HTMLAnchorElement>, "ref"> & {
    ref?: ((instance: HTMLAnchorElement | null) => void) | react.RefObject<HTMLAnchorElement> | null | undefined;
}, never>> & Omit<react.ForwardRefExoticComponent<LinkProps & react.RefAttributes<HTMLAnchorElement>>, keyof react.Component<any, {}, any>>;
declare const DisabledLinkButton: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<Omit<styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, never>, "ref"> & {
    ref?: ((instance: HTMLSpanElement | null) => void) | react.RefObject<HTMLSpanElement> | null | undefined;
}, never>> & Omit<styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, never>>, keyof react.Component<any, {}, any>>;
type LinkButtonProps = LinkProps & {
    readonly disabled?: boolean;
};
declare const LinkButton: ({ disabled, to, ...props }: LinkButtonProps) => JSX.Element;

type HorizontalRuleProps = {
    readonly color?: string;
};
declare const HorizontalRule: styled_components.IStyledComponent<"web", styled_components_dist_types.Substitute<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHRElement>, HTMLHRElement>, HorizontalRuleProps>>;

type ProjectTileProps = {
    readonly link: string;
    readonly image: string;
    readonly title: string;
    readonly subtitle: string;
    readonly size?: number;
    readonly backgroundColor?: string;
    readonly textBackgroundColor?: string;
};
declare const ProjectTile: ({ link, image, title, subtitle, size, backgroundColor, textBackgroundColor }: ProjectTileProps) => react_jsx_runtime.JSX.Element;

declare const StyledAnchor: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.AnchorHTMLAttributes<HTMLAnchorElement>, HTMLAnchorElement>, never>>;
declare const DisabledAnchor: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<Omit<styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, never>, "ref"> & {
    ref?: ((instance: HTMLSpanElement | null) => void) | react.RefObject<HTMLSpanElement> | null | undefined;
}, never>> & Omit<styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, never>>, keyof react.Component<any, {}, any>>;
type AnchorProps = React.AnchorHTMLAttributes<HTMLAnchorElement> & {
    readonly openInNewTab?: boolean;
    readonly disabled?: boolean;
};
declare const Anchor: ({ disabled, href, openInNewTab, ...props }: AnchorProps) => JSX.Element;

type NavLinkProps = {
    readonly link: string;
    readonly children?: JSX.Element | readonly JSX.Element[] | string;
};
declare const NavLink: ({ link, children }: NavLinkProps) => react_jsx_runtime.JSX.Element;
declare const NavText: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<Omit<styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>, "ref"> & {
    ref?: ((instance: HTMLHeadingElement | null) => void) | react.RefObject<HTMLHeadingElement> | null | undefined;
}, never>> & Omit<styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>>, keyof react.Component<any, {}, any>>;

type IconProps = React.HTMLAttributes<HTMLElement> & {
    readonly className: string;
};
declare const Icon: ({ className, ...props }: IconProps) => react_jsx_runtime.JSX.Element;

type BaseTheme = {
    readonly fontFamily: string;
    readonly background: {
        readonly color: string;
        readonly on: string;
    };
    readonly navbar: {
        readonly color: string;
        readonly on: string;
    };
    readonly surface: {
        readonly color: string;
        readonly on: string;
    };
    readonly inputs: {
        readonly color: string;
        readonly colorDisabled: string;
        readonly outlineRaised: string;
        readonly outlineLowered: string;
        readonly on: string;
        readonly onVariant: string;
        readonly onDisabled: string;
    };
    readonly primary: {
        readonly color: string;
        readonly on: string;
    };
    readonly secondary: {
        readonly color: string;
        readonly on: string;
    };
    readonly error: {
        readonly color: string;
        readonly on: string;
    };
};

declare const WHITE = "#ffffff";
declare const BLACK = "#000000";
declare const CC_BLUE_DARK = "#00687D";
declare const CC_BLUE = "#009FBF";
declare const OFF_WHITE = "#d8d8d8";
declare const GRAY_BLUISH = "#343A40";
declare const DARK_GRAY_BLUISH = "#212529";
declare const ALMOST_WHITE = "#fafafa";
declare const defaultLightTheme: BaseTheme;
declare const defaultDarkTheme: BaseTheme;
declare const defaultJustRed: BaseTheme;
type ThemeContextType = {
    readonly setTheme: (newTheme: string) => void;
    readonly theme: string;
};
declare const useThemeContext: () => ThemeContextType;
type ThemeContextProviderProps = WithChildren & {
    readonly themes?: readonly {
        readonly name: string;
        readonly theme: BaseTheme;
    }[];
};
declare const ThemeContextProvider: ({ children, themes }: ThemeContextProviderProps) => react_jsx_runtime.JSX.Element;

declare const Headline1: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>>;
declare const Headline2: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>>;
declare const Headline3: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>>;
declare const Headline4: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>>;
declare const Headline5: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>>;
declare const Headline6Css: styled_components.RuleSet<object>;
declare const Headline6: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>>;
declare const Subtitle1Css: styled_components.RuleSet<object>;
declare const Subtitle1: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>>;
declare const Subtitle2: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLHeadingElement>, HTMLHeadingElement>, never>>;
declare const Body1Css: styled_components.RuleSet<object>;
declare const Body1: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, never>>;
declare const Body2: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, never>>;
declare const Caption: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, never>>;
declare const ButtonTextCss: styled_components.RuleSet<object>;
declare const ButtonText: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, never>>;
declare const Overline: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLSpanElement>, HTMLSpanElement>, never>>;

declare const useClickOutside: (ref: RefObject<HTMLDivElement>, handler: (event: MouseEvent) => void) => void;

declare const usePrevious: <T>(value: T) => T | undefined;

declare const useUrlParams: () => {
    [key: string]: string;
};

declare const useInterval: (callback: () => void, delay: number) => void;

type AdditionalOptions$1<T> = {
    readonly requestData?: RequestInit;
    readonly skip?: boolean;
    readonly onComplete?: (data: T) => void;
    readonly onError?: (message: String) => void;
};
type ExtraData$1<T> = {
    readonly error: string | undefined;
    readonly setData: React.Dispatch<React.SetStateAction<T | undefined>>;
    readonly resetData: () => void;
    readonly refetch: () => void;
};
declare function useFetch<T>(url: string, options?: AdditionalOptions$1<T>): readonly [T | undefined, boolean, ExtraData$1<T>];

type AdditionalOptions<T> = {
    readonly requestData?: RequestInit;
    readonly shouldThrow?: boolean;
};
type ExtraData<T> = {
    readonly error: string | undefined;
};
declare function useQuery<T>(url: string, options?: AdditionalOptions<T>): readonly [(body?: string, pathParams?: string, queryParams?: string) => Promise<T | null>, boolean, ExtraData<T>];

type ToastContextType = {
    readonly pushToast: (component: JSX.Element) => void;
};
declare const useToast: () => ToastContextType;
type ToastProps = WithChildren & {
    readonly maxShown?: number;
};
declare const Toast: ({ children, maxShown }: ToastProps) => react_jsx_runtime.JSX.Element;

type TextToastProps = {
    readonly text: string;
};
declare const TextToast: ({ text }: TextToastProps) => react_jsx_runtime.JSX.Element;

declare const BackgroundWrapper: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;
declare const ModalContent: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;
type ModalProps = WithChildren & {
    readonly show: boolean;
    readonly requestClose?: () => void;
};
declare const Modal: ({ show, requestClose, children }: ModalProps) => react_jsx_runtime.JSX.Element;
declare const ModalNoBG: ({ children, show }: ModalProps) => react_jsx_runtime.JSX.Element;

type DualOptionModalProps = WithChildren & {
    readonly show: boolean;
    readonly requestClose?: () => void;
    readonly primaryText: string;
    readonly primaryLoading?: boolean;
    readonly onPrimaryClick: () => void;
    readonly secondaryText: string;
    readonly secondaryLoading?: boolean;
    readonly onSecondaryClick: () => void;
};
declare const DualOptionModal: ({ show, requestClose, children, primaryText, primaryLoading, onPrimaryClick, secondaryText, secondaryLoading, onSecondaryClick }: DualOptionModalProps) => react_jsx_runtime.JSX.Element;

type ConfirmationModalProps = {
    readonly show: boolean;
    readonly requestClose?: () => void;
    readonly text: ReactNode;
    readonly yesText: string;
    readonly yesLoading?: boolean;
    readonly onYesClick: () => void;
    readonly noText: string;
    readonly noLoading?: boolean;
    readonly onNoClick: () => void;
};
declare const ConfirmationModal: ({ show, requestClose, text, yesText, yesLoading, onYesClick, noText, noLoading, onNoClick }: ConfirmationModalProps) => react_jsx_runtime.JSX.Element;

declare const NotFound: () => react_jsx_runtime.JSX.Element;

declare const Card: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;
declare const CardHeader: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;
declare const CardContent: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;

declare const NavBar: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLElement>, HTMLElement>, never>>;
declare const SiteName: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<Omit<react_router_dom.LinkProps & react.RefAttributes<HTMLAnchorElement>, "ref"> & {
    ref?: ((instance: HTMLAnchorElement | null) => void) | react.RefObject<HTMLAnchorElement> | null | undefined;
}, never>> & Omit<react.ForwardRefExoticComponent<react_router_dom.LinkProps & react.RefAttributes<HTMLAnchorElement>>, keyof react.Component<any, {}, any>>;
declare const CenterContent: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;
declare const CollapsibleCenterContent: ({ children }: WithChildren) => react_jsx_runtime.JSX.Element;

type CollapsedNavbarProps = WithChildren & {
    readonly icon: string;
};
declare const CollapsedNavbar: ({ children, icon }: CollapsedNavbarProps) => react_jsx_runtime.JSX.Element;

declare const SpaceBetween: ({ children }: WithChildren) => react_jsx_runtime.JSX.Element;

type TableProps = React.TableHTMLAttributes<HTMLTableElement> & {
    readonly tableColumns?: string;
};
declare const Table: styled_components.IStyledComponent<"web", styled_components_dist_types.Substitute<react.DetailedHTMLProps<react.TableHTMLAttributes<HTMLTableElement>, HTMLTableElement>, TableProps>>;
declare const TH: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.ThHTMLAttributes<HTMLTableHeaderCellElement>, HTMLTableHeaderCellElement>, never>>;
declare const TD: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.TdHTMLAttributes<HTMLTableDataCellElement>, HTMLTableDataCellElement>, never>>;

declare const ButtonRow: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;

declare const ProjectTilesList: styled_components.IStyledComponent<"web", styled_components_dist_types.FastOmit<react.DetailedHTMLProps<react.HTMLAttributes<HTMLDivElement>, HTMLDivElement>, never>>;

type AccordionProps = WithChildren & React.InputHTMLAttributes<HTMLDivElement> & {
    readonly header: string;
    readonly defaultShow?: boolean;
};
declare const Accordion: ({ children, header, defaultShow, ...props }: AccordionProps) => react_jsx_runtime.JSX.Element;

declare const Elevation: {
    none: string;
    lowest: string;
    low: string;
    medium: string;
    high: string;
    highest: string;
};

declare const FontWeight: {
    THIN: number;
    EXTRA_LIGHT: number;
    LIGHT: number;
    NORMAL: number;
    MEDIUM: number;
    SEMI_BOLD: number;
    BOLD: number;
    EXTRA_BOLD: number;
    BLACK: number;
    EXTRA_BLACK: number;
};

declare const Opacity: {
    HOVER_NORMAL: string;
    HOVER_MEDIUM: string;
};

declare const device: {
    mobileS: string;
    mobileM: string;
    mobileL: string;
    tablet: string;
    laptop: string;
    laptopL: string;
    desktop: string;
    desktopL: string;
};

declare const TextHoverCss: styled_components.RuleSet<object>;

export { ALMOST_WHITE, Accordion, Anchor, BLACK, BackgroundWrapper, type BaseTheme, Body1, Body1Css, Body2, Button, ButtonRow, ButtonText, ButtonTextCss, CC_BLUE, CC_BLUE_DARK, Caption, Card, CardContent, CardHeader, CenterContent, CollapsedNavbar, CollapsibleCenterContent, ConfirmationModal, ContainedButton, DARK_GRAY_BLUISH, DisabledAnchor, DisabledLinkButton, Dropdown, DropdownContent, DropdownLinkItem, DualOptionModal, Elevation, FontWeight, GRAY_BLUISH, Headline1, Headline2, Headline3, Headline4, Headline5, Headline6, Headline6Css, HorizontalRule, Icon, Input, InputsFullWidth, InputsWrapper, Label, LinkButton, Loading, Modal, ModalContent, ModalNoBG, NavBar, NavLink, NavText, NotFound, OFF_WHITE, Opacity, Option, OutlinedButton, Overline, ProjectTile, ProjectTilesList, Select, SiteName, SpaceBetween, StyledAnchor, StyledLinkButton, Subtitle1, Subtitle1Css, Subtitle2, TD, TH, Table, type TableProps, TextArea, TextButton, TextHoverCss, TextToast, ThemeContextProvider, Toast, ToggleSwitch, TopLabeled, WHITE, type WithChildren, defaultDarkTheme, defaultJustRed, defaultLightTheme, device, useClickOutside, useFetch, useInterval, usePrevious, useQuery, useThemeContext, useToast, useUrlParams };
